@@ -1,4 +1,4 @@
-import pyautogui, re, time, os, shutil, keyboard, click, threading, pyperclip # type: ignore
+import pyautogui, re, time, os, shutil, keyboard, click, threading, pyperclip, easygui # type: ignore
 from datetime import datetime
 from os.path import exists
 from datetime import datetime
@@ -7,12 +7,10 @@ from pynput import keyboard as kbd # type: ignore
 
 kb = Controller()
 
-import easygui # type: ignore
-
 
 #-----------------------------------------------------
 #
-# Clickomat v1.0.5
+# Clickomat v1.0.6
 #
 #-----------------------------------------------------
 
@@ -164,7 +162,7 @@ class Clickomat:
                 exit()
 
         # Default Parameters
-        self.confidence           = 0.95
+        self.confidence           = 0.90
         self.autoswitch           = False
         self.autoswitch_pause     = 1
 
@@ -972,7 +970,7 @@ def run(version,path,clicklist,images,confidence,autoswitch,silent,step,noswitch
     if position: clipPositionLoop()
 
     if version:
-        print("Clickomat 1.0.5 is installed.\nYou may want to check if your version is up to date: pip list --outdated")
+        print("Clickomat 1.0.6 is installed.\nYou may want to check if your version is up to date: pip list --outdated")
         exit()
 
     case_path = path
